@@ -1,6 +1,6 @@
 package Courriel::Builder;
 {
-  $Courriel::Builder::VERSION = '0.28';
+  $Courriel::Builder::VERSION = '0.30';
 }
 
 use strict;
@@ -36,7 +36,6 @@ BEGIN {
         from
         to
         cc
-        bcc
         header
         plain_body
         html_body
@@ -158,7 +157,7 @@ sub _add_required_headers {
 }
 
 {
-    my $spec = { isa => NonEmptyStr };
+    my $spec = { isa => Str };
 
     sub subject {
         my ($subject) = pos_validated_list(
@@ -221,23 +220,6 @@ sub _add_required_headers {
     }
 }
 
-{
-    my $spec = { isa => EmailAddressStr, coerce => 1 };
-
-    sub bcc {
-        my $count = @_ ? @_ : 1;
-        my (@bcc) = pos_validated_list(
-            \@_,
-            ($spec) x $count,
-            MX_PARAMS_VALIDATE_NO_CACHE => 1,
-        );
-
-        @bcc = map { blessed($_) ? $_->format() : $_ } @bcc;
-
-        return { header => [ Bcc => join ', ', @bcc ] };
-    }
-}
-
 {
     my @spec = (
         { isa => NonEmptyStr },
@@ -475,7 +457,7 @@ Courriel::Builder - Build emails with sugar
 
 =head1 VERSION
 
-version 0.28
+version 0.30
 
 =head1 SYNOPSIS
 
@@ -521,7 +503,8 @@ them, ensuring that the email is RFC-compliant.
 
 =head2 subject($subject)
 
-This sets the subject of the email. It expects a single string.
+This sets the subject of the email. It expects a single string. You can pass
+an empty string, but not C<undef>.
 
 =head2 from($from)
 
@@ -538,11 +521,6 @@ L<Email::Address> objects.
 This sets the Cc header of the email. It expects a list of string and/or
 L<Email::Address> objects.
 
-=head2 bcc($from)
-
-This sets the Bcc header of the email. It expects a list of string and/or
-L<Email::Address> objects.
-
 =head2 header( $name => $value )
 
 This sets a header's value. You can call it as many times as you want, and you
